@@ -44,7 +44,6 @@
 #include <KSharedConfig>
 #include <KLocalizedString>
 #include <QIcon>
-#include <QDebug>
 
 #include <QCoreApplication>
 #include <QRegularExpression>
@@ -155,7 +154,7 @@ public:
     }
 };
 
-/* This filter selects only VS-compliant keys if Kleopatra is used in
+/* This filter selects only VS-NfD-compliant keys if Kleopatra is used in
  * CO_DE_VS mode.  */
 class DeVsCompliantKeyFilter : public DefaultKeyFilter
 {
@@ -163,7 +162,7 @@ public:
     DeVsCompliantKeyFilter()
         : DefaultKeyFilter()
     {
-        setName(i18n("VS-compliant Certificates"));
+        setName(i18n("VS-NfD-compliant Certificates"));
         setId(QStringLiteral("vs-compliant-certificates"));
         setSpecificity(UINT_MAX - 5); // overly high for ordering
     }
@@ -194,34 +193,40 @@ public:
 /* This filter gives valid keys (i.e. those where all UIDs are at
  * least fully valid) a light green background if Kleopatra is used in
  * CO_DE_VS mode.  */
-class KeyValidAppearanceFilter : public DefaultKeyFilter
+class KeyDeVSValidAppearanceFilter : public DefaultKeyFilter
 {
 public:
-    KeyValidAppearanceFilter()
+    KeyDeVSValidAppearanceFilter()
         : DefaultKeyFilter()
     {
-        setBgColor(QColor("lightgreen"));
+        // Ideally this would come from KColorScheme but we want to
+        // avoid a dependency against kconfigwidgets. So we take
+        // the color for positive background from breeze.
+        setBgColor(QColor(0xD5, 0xFA,  0xE2));
     }
     bool matches (const Key &key, MatchContexts contexts) const override
     {
-        return (contexts & Appearance) && Formatting::uidsHaveFullValidity(key);
+        return (contexts & Appearance) && Formatting::uidsHaveFullValidity(key) && Formatting::isKeyDeVs(key);
     }
 };
 
 /* This filter gives invalid keys (i.e. those where not all UIDs are
  * at least fully valid) a light red background if Kleopatra is used
  * in CO_DE_VS mode.  */
-class KeyNotValidAppearanceFilter : public DefaultKeyFilter
+class KeyNotDeVSValidAppearanceFilter : public DefaultKeyFilter
 {
 public:
-    KeyNotValidAppearanceFilter()
+    KeyNotDeVSValidAppearanceFilter()
         : DefaultKeyFilter()
     {
-        setBgColor(QColor("lightpink"));
+        // Ideally this would come from KColorScheme but we want to
+        // avoid a dependency against kconfigwidgets. So we take
+        // the color for negative background from breeze.
+        setBgColor(QColor(0xFA, 0xE9, 0xEB));
     }
     bool matches (const Key &key, MatchContexts contexts) const override
     {
-        return (contexts & Appearance) && !Formatting::uidsHaveFullValidity(key);
+        return (contexts & Appearance) && (!Formatting::uidsHaveFullValidity(key) || !Formatting::isKeyDeVs(key));
     }
 };
 
@@ -248,8 +253,8 @@ static std::vector<std::shared_ptr<KeyFilter>> defaultAppearanceFilters()
     std::vector<std::shared_ptr<KeyFilter> > result;
     if (Formatting::complianceMode() == QStringLiteral("de-vs")) {
         result.reserve(2);
-        result.push_back(std::shared_ptr<KeyFilter>(new KeyValidAppearanceFilter));
-        result.push_back(std::shared_ptr<KeyFilter>(new KeyNotValidAppearanceFilter));
+        result.push_back(std::shared_ptr<KeyFilter>(new KeyDeVSValidAppearanceFilter));
+        result.push_back(std::shared_ptr<KeyFilter>(new KeyNotDeVSValidAppearanceFilter));
     }
     return result;
 }
